%**********************************************************************
%    EXERCISES COMPUTATIONAL FLUID DYNAMICS
%
% EXEERCISE 1
% NAME MODULE: ns_1.m
% DATE:  May 1993 / January 2000
%**********************************************************************
% DESCRIPTION:
%    This module solves a convection-diffusion equation with
%    various discretisation methods. The individual methods
%    have been implemented in modules ns_1a.m, ns_1b.m, etc. 
%    The exact solution is computed in ns_exact.m 
% INPUT:
% N     number of grid points
% k     diffusioncoefficient
% OUTPUT:
% plots of the solution for eight methods:
%  i) upwind; ii) smart upwind iii) B3; iv) QUICK; v) central; 
%  vi) upwind nonuniform; vii) en viii) nonuniform central
%***********************************************************************
clf
% remove old arrays
clear x yex yupw ylam xrek yrek yexrek ew A  
%
% input of parameters
%
N=input('input  N:    ');
k=input('input  k:    ');
%
x=1/N*[1:1:N];                          % definition of uniform grid
for i=1:N
   yex(i)=ns_exact(x(i),k);             % compute exact solution
end
%
yupw=zeros(1,N);                % initialisation for plots
ylam=zeros(1,N);
yrek=zeros(1,N);
%
% upwind
%
methode='U';
ns_1a                      % compute upwind solution - yupw
subplot(331)
plot(x,yex,x,yupw)
axis([0 1 0 1])
title('upwind')
%
% smart-upwind
%
methode='S';
ns_1a
subplot(332)
plot(x,yex,x,yupw)
axis([0 1 0 1])
title('smart upwind')
%
% B3
%
lambda=0.5;
ns_1b                     % compute with lambda scheme - ylam
subplot(334)
plot(x,yex,x,ylam)
axis([0 1 0 1])
title('B3')
%
% quick
%
lambda=0.125;                 
ns_1b                     
subplot(335)
plot(x,yex,x,ylam)
axis([0 1 0 1])
title('QUICK')
%
% central
%
lambda=0.0;
ns_1b
subplot(336)
plot(x,yex,x,ylam)
axis([0 1 0 1])
title('central')
%
%
% nonuniform grid  - exact solution is determined in ns_1c.m 
%
% upwind nonuniform; Method U
%
methode='U';
ns_1c
subplot(337)
plot(xrek,yexrek,xrek,yrek)
axis([0 1 0 1])
title('upwind nonuniform ')
%
% central nonuniform; Method A
%
methode='A';
ns_1c
subplot(338)
plot(xrek,yexrek,xrek,yrek)
axis([0 1 0 1])
title('central nonuniform A')
%
% central nonuniform; Method B
%
methode='B';
ns_1c
subplot(339)
plot(xrek,yexrek,xrek,yrek)
axis([0 1 0 1])
title('central nonuniform B')
%
%
[V,D]=eig(A);               % determine eigenvalues of coeff. matrix A 
for i=1:N-1
   ew(i)=D(i,i);            % store eigenvalues in array ew 
end
%
pause
%
% print eigenvalues
%
ew'


